Django-photologue
=================
.. image:: https://img.shields.io/pypi/v/django-photologue.svg
    :target: https://pypi.python.org/pypi/django-photologue/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-photologue.svg
    :target: https://pypi.python.org/pypi/django-photologue/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/wheel/django-photologue.svg
    :target: https://pypi.python.org/pypi/django-photologue/
    :alt: Wheel Status
    
.. image:: https://travis-ci.org/jdriscoll/django-photologue.svg?branch=master
    :target: https://travis-ci.org/jdriscoll/django-photologue

.. image:: https://coveralls.io/repos/jdriscoll/django-photologue/badge.png
  :target: https://coveralls.io/r/jdriscoll/django-photologue

A powerful image management and gallery application for the Django web framework. Upload photos, group them into
galleries, apply effects such as watermarks.

Take a closer look
------------------
- We have a `demo website <http://www.django-photologue.net/>`_.
- We also have some `examples of sites using Photologue 
  <https://github.com/jdriscoll/django-photologue/wiki/Examples-and-forks>`_ on the wiki.

Documentation
-------------
Please head over to our `online documentation at ReadTheDocs <https://django-photologue.readthedocs.org/>`_ 
for instructions on installing and configuring this application.

Python 3? Amazon S3?
--------------------
Yes! Photologue is CI tested against both Python 2 and Python 3.

For S3, you'll have to install Boto, which for now is not compatible with Python 3 so you're stuck with Python 2.7...

Support
-------
If you have any questions or need help with any aspect of Photologue then please `join our mailing list
<http://groups.google.com/group/django-photologue>`_.

Travis CI status
----------------
We use Travis to check that the unit test suite is working against various combinations
of Python, Django, etc... `Click here for the full report <http://travis-ci.org/#!/jdriscoll/django-photologue>`_.
